@@ -14,6 +14,7 @@ logger = logging.getLogger(__name__)
 EVENTS_API_URL = 'https://events.pagerduty.com/v2/enqueue'
 DEFAULT_LOGS_PAYLOAD_LIMIT_BYTES = 10000
 HANDLER_IDENTIFIER = 'pagerduty'
+TIMEOUT_SECONDS = 10
 
 
 def initialize_monitor(hook_config, config, config_filename, monitoring_log_level, dry_run):
@@ -33,8 +34,10 @@ def initialize_monitor(hook_config, config, config_filename, monitoring_log_leve
 
     borgmatic.hooks.monitoring.logs.add_handler(
         borgmatic.hooks.monitoring.logs.Forgetful_buffering_handler(
-            HANDLER_IDENTIFIER, ping_body_limit, monitoring_log_level
-        )
+            HANDLER_IDENTIFIER,
+            ping_body_limit,
+            monitoring_log_level,
+        ),
     )
 
 
@@ -55,14 +58,15 @@ def ping_monitor(hook_config, config, config_filename, state, monitoring_log_lev
 
     try:
         integration_key = borgmatic.hooks.credential.parse.resolve_credential(
-            hook_config.get('integration_key'), config
+            hook_config.get('integration_key'),
+            config,
         )
     except ValueError as error:
         logger.warning(f'PagerDuty credential error: {error}')
         return
 
     logs_payload = borgmatic.hooks.monitoring.logs.format_buffered_logs_for_payload(
-        HANDLER_IDENTIFIER
+        HANDLER_IDENTIFIER,
     )
 
     hostname = platform.node()
@@ -86,7 +90,7 @@ def ping_monitor(hook_config, config, config_filename, state, monitoring_log_lev
                     'logs': logs_payload,
                 },
             },
-        }
+        },
     )
 
     if dry_run:
@@ -94,7 +98,12 @@ def ping_monitor(hook_config, config, config_filename, state, monitoring_log_lev
 
     logging.getLogger('urllib3').setLevel(logging.ERROR)
     try:
-        response = requests.post(EVENTS_API_URL, data=payload.encode('utf-8'))
+        response = requests.post(
+            EVENTS_API_URL,
+            data=payload.encode('utf-8'),
+            timeout=TIMEOUT_SECONDS,
+            headers={'User-Agent': 'borgmatic'},
+        )
         if not response.ok:
             response.raise_for_status()
     except requests.exceptions.RequestException as error:
